autowisp.database.data_model.condition_expression module — AutoWISP documentation

# autowisp.database.data_model.condition_expression module

## Class Inheritance Diagram

Define the ConditionExpression table for the pipeline

class autowisp.database.data_model.condition_expression.ConditionExpression(**kwargs)

  Bases: `DataModelBase`

  The table describing the Condition Expressions

  expression

    The expression to evaluate to determine if an image meets the condition.

  id

    A unique identifier for each row.

  notes

    Any user supplied notes describing the condition expression.

  timestamp

    When record was last changed